@@ -1,6 +1,7 @@
 package Acme::Opish;
 
-use vars qw($VERSION); $VERSION = '0.01';
+use vars qw($VERSION);
+$VERSION = '0.02';
 use base qw(Exporter);
 use vars qw(@EXPORT @EXPORT_OK);
 @EXPORT = @EXPORT_OK = qw(
@@ -138,6 +139,25 @@ sub _to_opish {
                 )                   # ...end capture.
             /$prefix$1/gisx;        # Add 'op' to what we captured.
         }
+        elsif (/^y[aeiouy]/i) {
+            # We don't want to prefix a non-vowel y.
+            s/
+                ^y                  # Our string starts with y!
+                (                   # Capture...
+                    [aeiouy]+       # consecutive vowels
+                    \B              # that do not terminate at a word boundry
+                    (?![aeiouy])    # that are not followed by another vowel
+                    |               # or
+                    [aeiouy]*       # any consecutive vowels
+                    [aiouy]         # with any non-e vowel following
+                    \b              # that terminates at a word boundry.
+                    |               # or
+                    [aeiouy]+       # consecutive vowels
+                    [aeiouy]        # with any vowel following
+                    \b              # that terminates at a word boundry.
+                )                   # ...end capture.
+            /y$prefix$1/gisx;        # Add 'op' to what we captured.
+        }
         else {
             # This regexp captures the "non-solitary, trailing e" vowels.
             s/
@@ -174,9 +194,7 @@ Acme::Opish - Prefix the audible vowels of words
 
   use Acme::Opish;
 
-  print join (', ',
-      enop('Hello Aeryk!')
-  ), "\n";
+  print enop('Hello Aeryk!');
   # Hopellopo Opaeropyk! 
 
   @opped = enop('five', '/literature/Wuthering_Heights.txt');
@@ -189,9 +207,7 @@ Acme::Opish - Prefix the audible vowels of words
   @opped = enop('xe', 'ze');        # xe, ze
 
   # Okay.  Why not add anything you want, instead of "op"?
-  print join (', ',
-      enop(-opish_prefix => 'ubb', 'Foo bar?')
-  ), "\n";
+  print enop(-opish_prefix => 'ubb', 'Foo bar?');
   # Fubboo bubbar?
 
 =head1 ABSTRACT
@@ -233,27 +249,27 @@ place of "op".
 
 =head2 no_silent_e ARRAY
 
-Add the given arguments to the "OK" list of words that are to be 
+Add the given arguments to the list of words that are to be 
 converted without regard for the "silent e".
 
-This function returns the number of keys in the "OK" list.
+This function returns the number of keys in the "not silent e" list.
 
 =head2 has_silent_e ARRAY
 
-Delete the given arguments from the "OK" list of words that are to be
+Delete the given arguments from the list of words that are to be
 converted with regard for the "silent e".
 
-This function returns the number of keys in the "OK" list.
+This function returns the number of keys in the "not silent e" list.
 
 =head1 SEE ALSO
 
 =head1 TO DO
 
-Make this thing preserve contiguous spaces.
+Make this thing preserve contiguous whitespace.
 
 Go in reverse.  That is "deop" text.
 
-Add more "OK" words".
+Add more "non-silent-e" words to the "OK" list.
 
 =head1 THANK YOU
 
